From 631d7b9b0878ca3842496b5719f9c5803335e150 Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Wed, 10 Aug 2011 22:19:39 +0000
Subject: rename the following methods: tqparent parent tqmask mask

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/basket@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 src/kcolorcombo2.h | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

(limited to 'src/kcolorcombo2.h')

diff --git a/src/kcolorcombo2.h b/src/kcolorcombo2.h
index e671dad..b76f538 100644
--- a/src/kcolorcombo2.h
+++ b/src/kcolorcombo2.h
@@ -49,7 +49,7 @@ class KColorPopup;
  * but this widget willn't be update and will still show the old one.\n
  * To be noticed of such color change and then update the widget with the new standard color, you can use one of those two methods:
  * @code
  * void TQWidgetDerivate::paletteChange(const TQPalette &oldPalette) { // TQWidgetDerivate is a tqparent or near custom widget
  *     theComboBox->setDefaultColor(theNewDefaultColor);
  *     TQWidget::paletteChange(oldPalette);
  * }
@@ -105,19 +105,19 @@ class KColorCombo2 : public TQComboBox
 
   public:
 	/**
 	 * Constructs a color combobox with tqparent @p tqparent called @p name.
 	 * @param color         The initial selected color. If it is not valid, the default one will then be selected.\n
 	 *                      But if @p color is invalid and there is no default color, the result is undefined.
 	 * @param defaultColor  The color to return if the user choose the default one. If it is not valid, the user willn't be allowed to choose a default one.
 	 */
-	KColorCombo2(const TQColor &color, const TQColor &defaultColor, TQWidget *tqparent = 0, const char *name = 0);
+	KColorCombo2(const TQColor &color, const TQColor &defaultColor, TQWidget *parent = 0, const char *name = 0);
 
 	/**
 	 * Constructs a color combobox with tqparent @p tqparent called @p name.\n
 	 * The user is not allowed to choose a default color, unless you call setDefaultColor() later.
 	 * @param color         The initial selected color. If it is invalid, the result is undefined.
 	 */
-	KColorCombo2(const TQColor &color, TQWidget *tqparent = 0L, const char *name = 0L);
+	KColorCombo2(const TQColor &color, TQWidget *parent = 0L, const char *name = 0L);
 
 	/**
 	 * Destroys the combobox.
@@ -225,7 +225,7 @@ class KColorCombo2 : public TQComboBox
 
 	/**
 	 * Draw an image of a colored rounded-rectangle.\n
-	 * This is like colorRectPixmap() but significantly faster because there is nothing to copy, and no transparency tqmask to create and apply.
+	 * This is like colorRectPixmap() but significantly faster because there is nothing to copy, and no transparency mask to create and apply.
 	 * @param painter   The painter where to draw the image.
 	 * @param x         The x coordinate on the @p painter where to draw the rectangle.
 	 * @param y         The y coordinate on the @p painter where to draw the rectangle.
@@ -314,7 +314,7 @@ class KColorPopup : public TQWidget
   Q_OBJECT
   TQ_OBJECT
   public:
-	KColorPopup(KColorCombo2 *tqparent);
+	KColorPopup(KColorCombo2 *parent);
 	~KColorPopup();
 	void retqlayout(); // updateGeometry() ??
   protected:
@@ -49,7 +49,7 @@ class KColorPopup;
  * To be noticed of such color change and then update the widget with the new standard color, you can use one of those two methods:
  * @code
- * void TQWidgetDerivate::paletteChange(const TQPalette &oldPalette) { // TQWidgetDerivate is a tqparent or near custom widget
+ * void TQWidgetDerivate::paletteChange(const TQPalette &oldPalette) { // TQWidgetDerivate is a parent or near custom widget
  *     theComboBox->setDefaultColor(theNewDefaultColor);
  *     TQWidget::paletteChange(oldPalette);
@@ -105,19 +105,19 @@ class KColorCombo2 : public TQComboBox
   public:
 	/**
-	 * Constructs a color combobox with tqparent @p tqparent called @p name.
+	 * Constructs a color combobox with parent @p parent called @p name.
 	 * @param color         The initial selected color. If it is not valid, the default one will then be selected.\n
 	 *                      But if @p color is invalid and there is no default color, the result is undefined.
@@ -105,19 +105,19 @@ class KColorCombo2 : public TQComboBox
 
 	/**
-	 * Constructs a color combobox with tqparent @p tqparent called @p name.\n
+	 * Constructs a color combobox with parent @p parent called @p name.\n
 	 * The user is not allowed to choose a default color, unless you call setDefaultColor() later.
 	 * @param color         The initial selected color. If it is invalid, the result is undefined.
-- 
cgit v1.2.1